@@ -25,6 +25,11 @@ from .annotate import Annotate
 from .._utils import patch_showwarnings
 from ...model import ProductType
 
+try:
+    import importlib.resources as importlib_resources
+except ImportError:
+    import importlib_resources
+
 
 class Run(Annotate):  # noqa: D101
 
@@ -136,6 +141,27 @@ class Run(Annotate):  # noqa: D101
                 self.warn("Output folder contains files that will be overwritten")
                 break
 
+    def _load_model_domains(self) -> typing.Set[str]:
+        if self.model is None:
+            self.info("Loading", "features from internal model", level=2)
+            resource_context = importlib_resources.path("gecco.types", "domains.tsv")
+            domains_file = resource_context.__enter__()
+        else:
+            self.info("Loading", "domain whitelist from", repr(self.model), level=2)
+            resource_context = contextlib.nullcontext()
+            domains_file = os.path.join(self.model, "domains.tsv")
+        try:
+            with open(domains_file) as f:
+                domains = set(filter(None, map(str.strip, f)))
+        except FileNotFoundError as err:
+            self.error("Could not find model domains:", repr(domains_file))
+            raise CommandExit(e.errno) from err
+        else:
+            self.success("Found", len(domains), "selected features", level=2)
+            return domains
+        finally:
+            resource_context.__exit__(None, None, None)
+
     def _predict_probabilities(self, genes):
         from ...crf import ClusterCRF
 
@@ -288,8 +314,11 @@ class Run(Annotate):  # noqa: D101
             else:
                 self.warn("No genes were found")
                 return 0
+            # use a whitelist for domain annotation, so that we only annotate
+            # with features that are useful for the CRF
+            whitelist = self._load_model_domains()
             # annotate domains and predict probabilities
-            genes = self._annotate_domains(genes)
+            genes = self._annotate_domains(genes, whitelist=whitelist)
             genes = self._predict_probabilities(genes)
             self._write_feature_table(genes)
             # extract clusters from probability vector
