@@ -191,6 +191,7 @@ class Gene:
             the source sequence, independent of the strandedness.
         end (`int`): The index of the rightmost nucleotide of the gene within
             the source sequence.
+        strand (`~gecco.model.Strand`): The strand where the gene is located.
         protein (`~gecco.model.Protein`): The protein translated from this
             gene.
         qualifiers (`dict`, optional): A dictionary of feature qualifiers that
@@ -558,7 +559,7 @@ class FeatureTable(Dumpable, Sized):
             frame[column] = getattr(self, column)
         return frame
 
-    def __iadd__(self, rhs: "FeatureTable") -> "FeatureTable":
+    def __iadd__(self, rhs: "FeatureTable") -> "FeatureTable":  # noqa: D105
         if not isinstance(rhs, FeatureTable):
             return NotImplemented
         for col in self.__annotations__:
@@ -722,7 +723,7 @@ class ClusterTable(Dumpable, Sized):
             table.domains.append(sorted(domains))
         return table
 
-    def __iadd__(self, rhs: "ClusterTable") -> "ClusterTable":
+    def __iadd__(self, rhs: "ClusterTable") -> "ClusterTable":  # noqa: D105
         if not isinstance(rhs, FeatureTable):
             return NotImplemented
         for col in self.__annotations__:
